@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 
 from moto.core.common_models import CloudFormationModel
@@ -22,6 +24,19 @@ from ..utils import (
 )
 
 
+class Attachment:
+    def __init__(self, eni: NetworkInterface):
+        self.attach_time = eni.attach_time
+        self.attachment_id = eni.attachment_id
+        self.delete_on_termination = eni.delete_on_termination
+        self.device_index = eni.device_index
+        self.network_card_index = 0
+        assert eni.instance is not None, "ENI must be attached to an instance"
+        self.instance_id = eni.instance.id
+        self.instance_owner_id = eni.instance.owner_id
+        self.status = "attached"
+
+
 class NetworkInterface(TaggedEC2Resource, CloudFormationModel):
     def __init__(
         self,
@@ -53,13 +68,15 @@ class NetworkInterface(TaggedEC2Resource, CloudFormationModel):
         self.attachment_id: Optional[str] = None
         self.attach_time: Optional[str] = None
         self.delete_on_termination = delete_on_termination
-        self.description = description
+        self.description = description or ""
         self.source_dest_check = True
 
         self.public_ip: Optional[str] = None
         self.public_ip_auto_assign = public_ip_auto_assign
         self.start()
         self.add_tags(tags or {})
+        self.requester_managed = False
+        self.requester_id = "AIDAIT2UOQQY3AUEMOTO"
         self.status = "available"
         self.mac_address = random_mac_address()
         self.interface_type = "interface"
@@ -116,8 +133,7 @@ class NetworkInterface(TaggedEC2Resource, CloudFormationModel):
 
         if self.subnet:
             vpc = self.ec2_backend.get_vpc(self.subnet.vpc_id)
-            # FIXME: Drop the `in` clause once the Vpc attribute is properly typed.
-            if vpc and vpc.enable_dns_hostnames in [True, "True", "true"]:
+            if vpc and vpc.enable_dns_hostnames:
                 self.private_dns_name = generate_dns_from_ip(self.private_ip_address)
                 for address in self.private_ip_addresses:
                     if address.get("Primary", None):
@@ -148,6 +164,17 @@ class NetworkInterface(TaggedEC2Resource, CloudFormationModel):
     def owner_id(self) -> str:
         return self.ec2_backend.account_id
 
+    @property
+    def attachment(self) -> Optional[Attachment]:
+        if self.attachment_id:
+            return Attachment(self)
+        return None
+
+    @property
+    def network_interface_ipv6_addresses_list(self) -> list[dict[str, str]]:
+        addresses = [{"Ipv6Address": ip} for ip in self.ipv6_addresses if ip]
+        return addresses
+
     @property
     def association(self) -> Dict[str, Any]:  # type: ignore[misc]
         association: Dict[str, Any] = {}
@@ -159,8 +186,21 @@ class NetworkInterface(TaggedEC2Resource, CloudFormationModel):
             if eip:
                 association["allocationId"] = eip.allocation_id or None
                 association["associationId"] = eip.association_id or None
+            association["natEnabled"] = True
         return association
 
+    @property
+    def availability_zone(self) -> str:
+        return self.subnet.availability_zone
+
+    @property
+    def vpc_id(self) -> str:
+        return self.subnet.vpc_id
+
+    @property
+    def subnet_id(self) -> str:
+        return self.subnet.id
+
     @staticmethod
     def cloudformation_name_type() -> str:
         return ""
@@ -336,10 +376,12 @@ class NetworkInterfaceBackend:
 
     def attach_network_interface(
         self, eni_id: str, instance_id: str, device_index: int
-    ) -> str:
+    ) -> Attachment:
         eni = self.get_network_interface(eni_id)
         instance = self.get_instance(instance_id)  # type: ignore[attr-defined]
-        return instance.attach_eni(eni, device_index)
+        instance.attach_eni(eni, device_index)
+        assert isinstance(eni.attachment, Attachment)
+        return eni.attachment
 
     def detach_network_interface(self, attachment_id: str) -> None:
         for eni in self.enis.values():
@@ -441,10 +483,12 @@ class NetworkInterfaceBackend:
 
     def unassign_ipv6_addresses(
         self, eni_id: str, ips: Optional[List[str]] = None
-    ) -> NetworkInterface:
+    ) -> list[str]:
+        unassigned_addresses = []
         eni = self.get_network_interface(eni_id)
         if ips:
             for ip in eni.ipv6_addresses.copy():
                 if ip in ips:
+                    unassigned_addresses.append(ip)
                     eni.ipv6_addresses.remove(ip)
-        return eni
+        return unassigned_addresses
