@@ -216,6 +216,9 @@ class ElasticMapReduceResponse(BaseResponse):
             job_flow_role=self._get_param("JobFlowRole"),
             service_role=self._get_param("ServiceRole"),
             auto_scaling_role=self._get_param("AutoScalingRole"),
+            ebs_root_volume_iops=self._get_param("EbsRootVolumeIops"),
+            ebs_root_volume_size=self._get_param("EbsRootVolumeSize"),
+            ebs_root_volume_throughput=self._get_param("EbsRootVolumeThroughput"),
             steps=steps_from_query_string(self._get_list_prefix("Steps.member")),
             visible_to_all_users=self._get_bool_param("VisibleToAllUsers", False),
             instance_attrs=instance_attrs,
@@ -259,7 +262,7 @@ class ElasticMapReduceResponse(BaseResponse):
                     "Only one AMI version and release label may be specified. "
                     "Provided AMI: {0}, release label: {1}."
                 ).format(ami_version, release_label)
-                raise ValidationException(message=message)
+                raise ValidationException(message)
         else:
             if ami_version:
                 kwargs["requested_ami_version"] = ami_version
@@ -274,10 +277,10 @@ class ElasticMapReduceResponse(BaseResponse):
                 ReleaseLabel(release_label) < ReleaseLabel("emr-5.7.0")
             ):
                 message = "Custom AMI is not allowed"
-                raise ValidationException(message=message)
+                raise ValidationException(message)
             elif ami_version:
                 message = "Custom AMI is not supported in this version of EMR"
-                raise ValidationException(message=message)
+                raise ValidationException(message)
 
         step_concurrency_level = self._get_param("StepConcurrencyLevel")
         if step_concurrency_level:
@@ -342,6 +345,8 @@ class ElasticMapReduceResponse(BaseResponse):
                     cluster.id, instance_groups[i], instance_group_result[i]
                 )
 
+        # TODO: Instances also must be created when `Instances.InstanceType` and `Instances.InstanceCount` are specified in the request.
+
         tags = self._get_list_prefix("Tags.member")
         if tags:
             self.backend.add_tags(
@@ -494,3 +499,12 @@ class ElasticMapReduceResponse(BaseResponse):
             ),
         )
         return EmptyResult()
+
+    def list_release_labels(self) -> ActionResult:
+        release_labels = self.backend.list_release_labels()
+        return ActionResult({"ReleaseLabels": release_labels})
+
+    def list_supported_instance_types(self) -> ActionResult:
+        release_label = self._get_param("ReleaseLabel")
+        instance_types = self.backend.list_supported_instance_types(release_label)
+        return ActionResult({"SupportedInstanceTypes": instance_types})
